from django.shortcuts import render
from django.conf import settings


class UnderConstructionMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        if settings.UNDER_CONSTRUCTION:
            return render(request, settings.UNDER_CONSTRUCTION_TEMPLATE)
        return self.get_response(request)



import setuptools

exec(open('django_underconstruction/version.py').read())

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='django-underconstruction',
    version=__version__,
    author='Koen Woortman',
    author_email='koensw@outlook.com',
    url='https://github.com/koenwoortman/django-underconstruction',
    description="django-underconstruction shows an under construction page",
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    include_package_data=True,
    python_requires='>=3.6',
    install_requires=['Django>=2.2'],
    license='MIT',
    classifiers=[
        'Framework :: Django',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
)



from django.conf import settings


if not hasattr(settings, 'UNDER_CONSTRUCTION'):
    settings.UNDER_CONSTRUCTION = False

if not hasattr(settings, 'UNDER_CONSTRUCTION_TEMPLATE'):
    settings.UNDER_CONSTRUCTION_TEMPLATE = 'django_underconstruction/construction.html'
